Split out isrg from ssr and reorient build graph to make interpreter build 2x faster (#2969)

* split out isrg and core-types to speed up interpreter build
This commit is contained in:
Jonathan Kelley authored and GitHub committed 2024-09-16 16:49:06 -07:00
1 parent f0d814fede
commit 143ad749ea
28 files changed
+197 -231

No files matched your search

+1 -1
View File
@@ -2,7 +2,7 @@ use crate::dom::WebsysDom;
use dioxus_core::prelude::*;
use dioxus_core::WriteMutations;
use dioxus_core::{AttributeValue, ElementId};
use dioxus_html::event_bubbles;
use dioxus_core_types::event_bubbles;
use dioxus_interpreter_js::minimal_bindings;
use wasm_bindgen::JsCast;
use wasm_bindgen::JsValue;